SystemOrganization addCategory: #'Pier-Core'!

!WAPlatform methodsFor: '*pier-core' stamp: 'jf 9/23/2009 16:25'!
pierPragmaCompilerClass
	"Return a compiler that is capable of compiling methods with method pragmas."
	
	self subclassResponsibility! !

WAPackage subclass: #PRPackage
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Core'!

!PRPackage class methodsFor: 'accessing' stamp: 'jf 9/23/2009 15:01'!
pierCore
	^ self new
		name: 'Pier-Core';
		addDependency: 'Magritte-Model';
		addDependency: 'Seaside-Platform';
		yourself! !

WAPlatformError subclass: #PRError
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Core'!

WAPlatformObject subclass: #PRBasicObject
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Core'!

!PRBasicObject class methodsFor: 'error handling' stamp: 'jf 9/18/2009 15:40'!
defaultErrorClass
	^ PRError! !

PRBasicObject subclass: #PRObject
	instanceVariableNames: 'properties'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Core'!

!PRObject commentStamp: 'jf 9/18/2009 15:47' prior: 0!
I am a superclass of most objects within Pier. I hold a dictionary of properties, so that users can easily annotate me with new values. I am visitable.!

!PRObject class methodsFor: 'testing' stamp: 'lr 3/9/2006 11:30'!
isAbstract
	^ true! !

!PRObject class methodsFor: 'instance-creation' stamp: 'jf 9/18/2009 15:41'!
new
	"Create a new instance of this class and checks if it isn't abstract."

	self isAbstract
		ifTrue: [ self error: self name , ' is abstract.' ].
	^ super new! !

!PRObject class methodsFor: 'reflection' stamp: 'lr 3/9/2006 11:30'!
withAllConcreteClasses
	^ Array streamContents: [ :stream |
		self withAllConcreteClassesDo: [ :each |
			stream nextPut: each ] ]! !

!PRObject class methodsFor: 'reflection' stamp: 'lr 3/9/2006 11:30'!
withAllConcreteClassesDo: aBlock
	self withAllSubclassesDo: [ :each |
		each isAbstract ifFalse: [
			aBlock value: each ] ]! !

!PRObject methodsFor: 'visiting' stamp: 'lr 4/10/2007 21:49'!
accept: aVisitor
	"Dispatch to ==aVisitor== depending on the receiver."! !

!PRObject methodsFor: 'private' stamp: 'lr 3/5/2007 14:03'!
errorPropertyNotFound: aSelector
	MAPropertyError signal: 'Property ' , aSelector , ' not found.'! !

!PRObject methodsFor: 'testing' stamp: 'lr 4/10/2007 21:49'!
hasProperty: aKey
	"Test if the property ==aKey== is defined within the receiver."

	^ self properties includesKey: aKey! !

!PRObject methodsFor: 'copying' stamp: 'lr 3/9/2006 11:29'!
postCopy
	super postCopy.
	properties := properties copy! !

!PRObject methodsFor: 'copying' stamp: 'lr 3/9/2006 11:29'!
postCopyTo: anObject! !

!PRObject methodsFor: 'accessing-properties' stamp: 'lr 5/28/2006 17:01'!
properties
	"Answer the property dictionary of the receiver."

	^ properties ifNil: [ properties := Dictionary new ]! !

!PRObject methodsFor: 'accessing-properties' stamp: 'lr 4/10/2007 21:49'!
propertyAt: aKey
	"Answer the value of the property ==aKey==, raises an error if the property doesn't exist."

	^ self propertyAt: aKey ifAbsent: [ self errorPropertyNotFound: aKey ]! !

!PRObject methodsFor: 'accessing-properties' stamp: 'lr 4/10/2007 21:49'!
propertyAt: aKey ifAbsent: aBlock
	"Answer the value of the property ==aKey==, or the result of ==aBlock== if the property doesn't exist."

	^ self properties at: aKey ifAbsent: aBlock! !

!PRObject methodsFor: 'accessing-properties' stamp: 'lr 4/10/2007 21:49'!
propertyAt: aKey ifAbsentPut: aBlock
	"Answer the value of the property ==aKey==, or if the property doesn't exist adds and answers the result of evaluating ==aBlock==."

	^ self properties at: aKey ifAbsentPut: aBlock! !

!PRObject methodsFor: 'accessing-properties' stamp: 'lr 4/10/2007 21:50'!
propertyAt: aKey put: aValue
	"Adds or replaces the property ==aKey== with ==aValue==."

	^ self properties at: aKey put: aValue! !

!WAPlatformObject class methodsFor: '*pier-core' stamp: 'jf 9/23/2009 16:24'!
usesMethodPragmas
	"Indicate that this class requires a pragma-capable compiler"
	
	^ false! !
